@@ -9,7 +9,7 @@ use Math::BigNum qw();
 
 use Class::Multimethods qw();
 
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 
 =encoding utf8
 
@@ -19,7 +19,7 @@ Math::BigNum::Inf - Represents the +/-Infinity value.
 
 =head1 VERSION
 
-Version 0.19
+Version 0.20
 
 =head1 SYNOPSIS
 
@@ -1617,6 +1617,8 @@ Class::Multimethods::multimethod brsft => qw(Math::BigNum::Inf Math::BigNum::Nan
 *harmreal  = \&nan;
 *kronecker = \&nan;
 *valuation = \&nan;
+*remove    = \&nan;
+*bremove   = \&bnan;
 
 # log(+/-Inf) = +Inf
 Class::Multimethods::multimethod log => qw(Math::BigNum::Inf) => \&inf;
