@@ -7,7 +7,7 @@ use warnings;
 use Math::GMPq qw();
 use Math::BigNum qw();
 
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 
 =encoding utf8
 
@@ -17,7 +17,7 @@ Math::BigNum::Nan - Represents the Not-a-Number value.
 
 =head1 VERSION
 
-Version 0.19
+Version 0.20
 
 =head1 SYNOPSIS
 
@@ -463,6 +463,9 @@ sub length { 0 }
 *kronecker = \&nan;
 *valuation = \&nan;
 
+*remove  = \&nan;
+*bremove = \&_self;
+
 *next_prime = \&nan;    # next prime after NaN? Hmm...
 *agm        = \&nan;
 *hypot      = \&nan;
